@@ -85,6 +85,7 @@ cvar_t devstats = {"devstats","0",CVAR_NONE}; //johnfitz -- track developer stat
 
 cvar_t	campaign = {"campaign","0",CVAR_NONE}; // for the 2021 rerelease
 cvar_t	horde = {"horde","0",CVAR_NONE}; // for the 2021 rerelease
+cvar_t	sv_cheats = {"sv_cheats","0",CVAR_NONE}; // for the 2021 rerelease
 
 devstats_t dev_stats, dev_peakstats;
 overflowtimes_t dev_overflows; //this stores the last time overflow messages were displayed, not the last time overflows occured
@@ -286,6 +287,7 @@ void Host_InitLocal (void)
 
 	Cvar_RegisterVariable (&campaign);
 	Cvar_RegisterVariable (&horde);
+	Cvar_RegisterVariable (&sv_cheats);
 
 	Cvar_RegisterVariable (&pausable);
 
