@@ -256,8 +256,8 @@ void Key_Console (int key)
 
 		// If the last two lines are identical, skip storing this line in history 
 		// by not incrementing edit_line
-		if (strcmp(workline, key_lines[(edit_line-1)&31]))
-			edit_line = (edit_line + 1) & 31;
+		if (strcmp(workline, key_lines[(edit_line - 1) & (CMDLINES - 1)]))
+			edit_line = (edit_line + 1) & (CMDLINES - 1);
 
 		history_line = edit_line;
 		key_lines[edit_line][0] = ']';
@@ -355,11 +355,11 @@ void Key_Console (int key)
 		len = strlen(workline);
 		if ((int)len == key_linepos)
 		{
-			len = strlen(key_lines[(edit_line + 31) & 31]);
+			len = strlen(key_lines[(edit_line + (CMDLINES - 1)) & (CMDLINES - 1)]);
 			if ((int)len <= key_linepos)
 				return; // no character to get
 			workline += key_linepos;
-			*workline = key_lines[(edit_line + 31) & 31][key_linepos];
+			*workline = key_lines[(edit_line + (CMDLINES - 1)) & (CMDLINES - 1)][key_linepos];
 			workline[1] = 0;
 			key_linepos++;
 		}
@@ -377,7 +377,7 @@ void Key_Console (int key)
 		history_line_last = history_line;
 		do
 		{
-			history_line = (history_line - 1) & 31;
+			history_line = (history_line - 1) & (CMDLINES - 1);
 		} while (history_line != edit_line && !key_lines[history_line][1]);
 
 		if (history_line == edit_line)
@@ -387,8 +387,9 @@ void Key_Console (int key)
 		}
 
 		key_tabpartial[0] = 0;
-		Q_strcpy(workline, key_lines[history_line]);
-		key_linepos = Q_strlen(workline);
+		len = strlen(key_lines[history_line]);
+		memmove(workline, key_lines[history_line], len+1);
+		key_linepos = (int)len;
 		return;
 
 	case K_DOWNARROW:
@@ -399,13 +400,20 @@ void Key_Console (int key)
 
 		do
 		{
-			history_line = (history_line + 1) & 31;
+			history_line = (history_line + 1) & (CMDLINES - 1);
 		} while (history_line != edit_line && !key_lines[history_line][1]);
 
 		if (history_line == edit_line)
-			Q_strcpy(workline, current);
-		else	Q_strcpy(workline, key_lines[history_line]);
-		key_linepos = Q_strlen(workline);
+		{
+			len = strlen(current);
+			memcpy(workline, current, len+1);
+		}
+		else
+		{
+			len = strlen(key_lines[history_line]);
+			memmove(workline, key_lines[history_line], len+1);
+		}
+		key_linepos = (int)len;
 		return;
 
 	case K_INS:
