@@ -1607,6 +1607,19 @@ static void PF_makestatic (void)
 			bits |= B_LARGEFRAME;
 		if (ent->alpha != ENTALPHA_DEFAULT)
 			bits |= B_ALPHA;
+
+		if (sv.protocol == PROTOCOL_RMQ)
+		{
+			eval_t* val;
+			val = GetEdictFieldValue(ent, "scale");
+			if (val)
+				ent->scale = ENTSCALE_ENCODE(val->_float);
+			else
+				ent->scale = ENTSCALE_DEFAULT;
+
+			if (ent->scale != ENTSCALE_DEFAULT)
+				bits |= B_SCALE;
+		}
 	}
 
 	if (bits)
@@ -1641,6 +1654,9 @@ static void PF_makestatic (void)
 		MSG_WriteByte (&sv.signon, ent->alpha);
 	//johnfitz
 
+	if (bits & B_SCALE)
+		MSG_WriteByte (&sv.signon, ent->scale);
+
 // throw the entity away now
 	ED_Free (ent);
 }
